@@ -607,7 +607,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                     cartaporte_ubicacion_destino.setAttribute('NombreDestinatario', ubicacion_data.get('NombreDestinatario'))
                     cartaporte_ubicacion_destino.setAttribute('FechaHoraProgLlegada', ubicacion_data.get('FechaHoraProgLlegada'))
                     cartaporte_ubicacion.appendChild(cartaporte_ubicacion_destino)
-                    total_distancia_recorrida += int(ubicacion_data.get('DistanciaRecorrida'))
+                    total_distancia_recorrida += float(ubicacion_data.get('DistanciaRecorrida'))
 
                 cartaporte_ubicacion_domicilio = self.dom.createElement('cartaporte:Domicilio')
                 cartaporte_ubicacion_domicilio.setAttribute('Calle', ubicacion_data.get('Calle'))
